@@ -37,13 +37,13 @@ sub probe ($$) {
     my ($self, $obj) = @_;
 
     if ($self->{-ctx}->{-platform}->id() =~ m/FreeBSD/i) {
-        my $hwDiskInfoENTRY = undef; #N/A
+        my @hwDiskInfoENTRY = undef; #N/A
     }
     elsif ($self->{-ctx}->{-platform}->id() =~ m/Linux/i) {
-        my $hwDiskInfoENTRY = undef; #N/A
+        my @hwDiskInfoENTRY = undef; #N/A
     }
     elsif($self->{-ctx}->{-platform}->id() =~ m/SunOS/i) {
-        my $hwDiskInfoENTRY = undef;
+        my @hwDiskInfoENTRY = undef;
 
         #   local workspace
         my $out; my $raw; my $arch; my $new;
