@@ -477,7 +477,7 @@ package main;
 
 #   parameters (defaults)
 my $opt = {
-    'config'    => "@sysconfdir@/snmpdx.cfg",
+    'config'    => "@sysconfdir@/snmpdx/snmpdx.cfg",
     'version'   => 0,
     'help'      => 0,
     'tmpdir'    => ($ENV{TMPDIR} || $ENV{TEMPDIR} || "/tmp"),
